# td-ml-activation-stats

## Introduction

This Python Library allows you to extract Activation stats from the TD Activations API

## Input Params

`config.yml`: The workflow `YAML` file contains the params that are required by this library to extract the neded information.


`Copyright © 2023 Treasure Data, Inc. (or its affiliates). All rights reserved`


